summaryrefslogtreecommitdiff
path: root/TAO/tao/Invocation.h
diff options
context:
space:
mode:
authormarina <marina@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2000-09-14 01:06:54 +0000
committermarina <marina@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2000-09-14 01:06:54 +0000
commit4898cebc78bfce27fe3b997fea910ed64c7dd2ee (patch)
tree59f279bfc60cf691e661531940d1d2c7c12255d5 /TAO/tao/Invocation.h
parent9fd348781e6e9d32473d112d6801a8e44ccd23c3 (diff)
downloadATCD-4898cebc78bfce27fe3b997fea910ed64c7dd2ee.tar.gz
ChangeLogTag:Wed Sep 13 19:15:01 2000 Marina Spivak <marina@cs.wustl.edu>
Diffstat (limited to 'TAO/tao/Invocation.h')
-rw-r--r--TAO/tao/Invocation.h17
1 files changed, 10 insertions, 7 deletions
diff --git a/TAO/tao/Invocation.h b/TAO/tao/Invocation.h
index 260b786208c..1cbad8a5017 100644
--- a/TAO/tao/Invocation.h
+++ b/TAO/tao/Invocation.h
@@ -45,6 +45,7 @@
struct TAO_Exception_Data;
class TAO_Profile;
class TAO_Transport;
+class TAO_Endpoint;
enum TAO_Invoke_Status
{
@@ -106,14 +107,13 @@ public:
TAO_OutputCDR &out_stream (void);
// Return the underlying output stream.
- TAO_Profile *select_profile_based_on_policy (
- CORBA_Environment &ACE_TRY_ENV = TAO_default_environment ()
- )
+ void select_endpoint_based_on_policy (CORBA_Environment &ACE_TRY_ENV
+ = TAO_default_environment ())
ACE_THROW_SPEC ((CORBA::SystemException));
// Select the profile we will use to in this invocation, based on
// policies for this object. (Currently the decision is based on a
// single Policy, TAO::Client_Priority_Policy.) I think this
// function may be more appropriate in TAO_Stub class.
+
protected:
void start (CORBA_Environment &ACE_TRY_ENV =
TAO_default_environment ())
@@ -173,7 +173,10 @@ protected:
// This invocation is using this transport, may change...
TAO_Profile *profile_;
- // This invocation is using this transport, may change...
+ // This invocation is this profile.
+
+ TAO_Endpoint *endpoint_;
+ // This invocation is using this endpoint from <profile_>.
ACE_Time_Value max_wait_time_value_;
ACE_Time_Value *max_wait_time_;
@@ -106,14 +107,13 @@ public:
ACE_THROW_SPEC ((CORBA::SystemException));
- // Select the profile we will use to in this invocation, based on
- // policies for this object. (Currently the decision is based on a
- // single Policy, TAO::Client_Priority_Policy.) I think this
+ // Select the endpoint (and profile) we will use to in this
+ // invocation, based on TAO::Client_Priority_Policy.) I think this
// function may be more appropriate in TAO_Stub class.